@@ -42,18 +42,13 @@ class CommandController(object):
         execute it. If *argv* is |None|, ``sys.argv`` is used.
         """
         # print help and exit if no args
-        no_args = len(argv if argv else sys.argv) == 1
-        if no_args:
+        arg_count = len(argv if argv else sys.argv)
+        if arg_count < 2:
             self._parser.print_help()
             sys.exit(1)
+
         args = self._parser.parse_args(argv)
         command = args.command
-        # # this try block is required to work around Python 3.3 argparse bug
-        # try:
-        #     command = args.command
-        # except AttributeError:
-        #     self._parser.print_help()
-        #     sys.exit(1)
         command.validate(args)
         command.execute(args, self._app_controller)
 
